@@ -296,7 +296,18 @@ def get_file_type(f):
                 root = tree.getroot()
                 return 'tcx'
             except:
-                return 'unknown'
+                try:
+                    with open(path, 'r') as fop:
+                        input = fop.read()
+                        input = strip_control_characters(input)
+                    with open('temp_xml.tcx','w') as fout:
+                        fout.write(input)
+
+                    tree = etree.parse('temp_xml.tcx')
+                    os.remove('temp_xml.tcx')
+                    return 'tcx'
+                except:
+                    return 'unknown'
         if extension == '.gpx':
             try:
                 tree = etree.parse(f)
@@ -333,8 +344,18 @@ def get_file_type(f):
             root = tree.getroot()
             return 'tcx'
         except:
-            return 'unknown'
+            try:
+                with open(f, 'r') as fop:
+                    input = fop.read()
+                    input = strip_control_characters(input)
+                with open('temp_xml.tcx','w') as ftemp:
+                    ftemp.write(input)
 
+                tree = etree.parse('temp_xml.tcx')
+                os.remove('temp_xml.tcx')
+                return 'tcx'
+            except:
+                return 'unknown'
     if extension == '.gpx':
         try:
             tree = etree.parse(f)
@@ -806,6 +827,14 @@ class CSVParser(object):
             ' longitude',
         ]
 
+        try:
+            x = self.df['TimeStamp (sec)']
+        except KeyError:
+            cols = self.df.columns
+            for col in cols:
+                if 'TimeStamp ' in col:
+                    self.df['TimeStamp (sec)'] = self.df[col]
+
         self.columns = {c: c for c in self.defaultcolumnnames}
 
     def to_standard(self):
@@ -2011,6 +2040,11 @@ class RowPerfectParser(CSVParser):
             'time',
             ' latitude',
             ' longitude',
+            'work_per_pulse'
+        ]
+
+        self.defaultcolumnnames += [
+            'driveenergy'
         ]
 
 
